@@ -3,7 +3,7 @@
 """ LinkedIn """
 
 __author__ = 'Mike Helmick <mikehelmick@me.com>'
-__version__ = '0.1.3'
+__version__ = '0.1.5'
 
 import urllib
 
@@ -27,7 +27,15 @@ except ImportError:
             raise ImportError('A json library is required to use this python library. Lol, yay for being verbose. ;)')
 
 
-class LinkedinAPIError(Exception): pass
+class LinkedinAPIError(Exception):
+    def __init__(self, message, code=None):
+        self.message = message
+        self.code = code
+
+    def __str__(self):
+        return repr(self.message)
+
+        
 class LinkedinAuthError(LinkedinAPIError): pass
 
 
@@ -157,7 +165,7 @@ class LinkedinAPI(object):
 
         status = int(resp['status'])
         if status < 200 or status >= 300:
-            raise LinkedinAPIError('Error Code: %d, Message: %s' % (status, content['message']))
+            raise LinkedinAPIError('Error Code: %d, Message: %s' % (status, content['message']), status)
 
         return content
 
